package cn.com.infosec.crypto.engines;

import cn.com.infosec.crypto.AsymmetricBlockCipher;
import cn.com.infosec.crypto.CipherParameters;
import cn.com.infosec.crypto.params.ParametersWithRandom;
import cn.com.infosec.crypto.params.RSABlindingParameters;
import cn.com.infosec.crypto.params.RSAKeyParameters;
import java.math.BigInteger;

public class RSABlindingEngine implements AsymmetricBlockCipher {
   private RSACoreEngine core;
   private RSAKeyParameters key;
   private BigInteger blindingFactor;
   private boolean forEncryption;

   public RSABlindingEngine() {
      RSABlindingEngine var10000 = this;
      super();
      RSACoreEngine var1;
      var1 = new RSACoreEngine.<init>();
      var10000.core = var1;
   }

   private BigInteger blindMessage(BigInteger msg) {
      return msg.multiply(this.blindingFactor.modPow(this.key.getExponent(), this.key.getModulus())).mod(this.key.getModulus());
   }

   private BigInteger unblindMessage(BigInteger blindedMsg) {
      RSABlindingEngine var10001 = this;
      BigInteger var2 = this.key.getModulus();
      return blindedMsg.multiply(var10001.blindingFactor.modInverse(var2)).mod(var2);
   }

   public void init(boolean forEncryption, CipherParameters param) {
      RSABlindingParameters param1;
      if (param instanceof ParametersWithRandom) {
         param1 = (RSABlindingParameters)((ParametersWithRandom)param).getParameters();
      } else {
         param1 = (RSABlindingParameters)param;
      }

      this.core.init(forEncryption, param1.getPublicKey());
      this.forEncryption = forEncryption;
      this.key = param1.getPublicKey();
      this.blindingFactor = param1.getBlindingFactor();
   }

   public int getInputBlockSize() {
      return this.core.getInputBlockSize();
   }

   public int getOutputBlockSize() {
      return this.core.getOutputBlockSize();
   }

   public byte[] processBlock(byte[] in, int inOff, int inLen) {
      BigInteger in1 = this.core.convertInput(in, inOff, inLen);
      if (this.forEncryption) {
         in1 = this.blindMessage(in1);
      } else {
         in1 = this.unblindMessage(in1);
      }

      return this.core.convertOutput(in1);
   }
}
